@@ -1,16 +1,22 @@
+#' @importFrom htmltools HTML
 build_details <- function(text = '', summary = '', state = 'open', 
-                          lang = 'r', output = 'console',...){
+                          lang = 'r', output = 'console', comment = NA, ...){
   
-  structure(
+  ret <- structure(
     paste(
     start_details(state,summary),
-    body_details(lang,capture.print(text,...)),
+    body_details(lang,capture.print(text,comment,...)),
     end_details(),
     sep='\n\n'),
     file = details_env$f_png,
     class = sprintf('details_%s',output)
   )
   
+  if(output=='html'){
+    ret <- htmltools::HTML(ret)
+  }
+    
+  ret
 }
 
 build_tooltip <- function(txt = '',tooltip = NULL){
